==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/eventing/contrib/github/v1alpha1/GitHubSourceListBuilder.java <==
package io.fabric8.knative.eventing.contrib.github.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class GitHubSourceListBuilder extends GitHubSourceListFluentImpl<GitHubSourceListBuilder> implements VisitableBuilder<GitHubSourceList,GitHubSourceListBuilder> {

    GitHubSourceListFluent<?> fluent;
    Boolean validationEnabled;

    public GitHubSourceListBuilder() {
        this(true);
    }

    public GitHubSourceListBuilder(Boolean validationEnabled) {
        this(new GitHubSourceList(), validationEnabled);
    }

    public GitHubSourceListBuilder(GitHubSourceListFluent<?> fluent) {
        this(fluent, true);
    }

    public GitHubSourceListBuilder(GitHubSourceListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new GitHubSourceList(), validationEnabled);
    }

    public GitHubSourceListBuilder(GitHubSourceListFluent<?> fluent,GitHubSourceList instance) {
        this(fluent, instance, true);
    }

    public GitHubSourceListBuilder(GitHubSourceListFluent<?> fluent,GitHubSourceList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public GitHubSourceListBuilder(GitHubSourceList instance) {
        this(instance,true);
    }

    public GitHubSourceListBuilder(GitHubSourceList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.contrib.github.v1alpha1.EditableGitHubSourceList build() {
        EditableGitHubSourceList buildable = new EditableGitHubSourceList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        GitHubSourceListBuilder that = (GitHubSourceListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/eventing/contrib/github/v1alpha1/GitHubSourceListBuilder.java <==
package io.fabric8.knative.eventing.contrib.github.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class GitHubSourceListBuilder extends GitHubSourceListFluentImpl<GitHubSourceListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<GitHubSourceList,GitHubSourceListBuilder> {

    GitHubSourceListFluent<?> fluent;
    Boolean validationEnabled;

    public GitHubSourceListBuilder() {
        this(true);
    }

    public GitHubSourceListBuilder(Boolean validationEnabled) {
        this(new GitHubSourceList(), validationEnabled);
    }

    public GitHubSourceListBuilder(GitHubSourceListFluent<?> fluent) {
        this(fluent, true);
    }

    public GitHubSourceListBuilder(GitHubSourceListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new GitHubSourceList(), validationEnabled);
    }

    public GitHubSourceListBuilder(GitHubSourceListFluent<?> fluent,GitHubSourceList instance) {
        this(fluent, instance, true);
    }

    public GitHubSourceListBuilder(GitHubSourceListFluent<?> fluent,GitHubSourceList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public GitHubSourceListBuilder(GitHubSourceList instance) {
        this(instance,true);
    }

    public GitHubSourceListBuilder(GitHubSourceList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.contrib.github.v1alpha1.EditableGitHubSourceList build() {
        EditableGitHubSourceList buildable = new EditableGitHubSourceList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        GitHubSourceListBuilder that = (GitHubSourceListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
